// Copyright (C) 2022 - Manish Joshi
//
// This file is a part of pendulumgui toolbox.
//
// Date of creation: 23 Feb, 2022
//

function pendulumgui()
	delete(figure(995, 'visible','off'))

	//***************** Main Figure.*******************//

	Pendulum.App = figure(995,....
	'figure_position',[285,141],....
	'figure_size',[1400,700],....
	'background',[17],....
	'figure_name','Simple Pendulum',....
	'dockable','off',....
	'infobar_visible','on',....
	'toolbar_visible','off',....
	'menubar_visible','off',....
	'default_axes','off',....
	'visible','off');
	Pendulum.App.info_message = '## Created by Manish Joshi';

	//================== Layout Constraints ==============//

	Pendulum.Const = createConstraints("gridbag",....
	[1, 1, 1, 1], [1, 1], "horizontal", "left", [5, 5]);

	//=================== Pendulum Frame.================//

	Pendulum.PendulumFrame = uicontrol(Pendulum.App,....
	'unit','normalized',....
	'BackgroundColor',[0.1,0.6,0.4],....
	'Position',[0,0.3,0.5,0.7],....
	'Relief','ridge',...
	'Style','frame');

	//---------------------Pendulum Axis.----------------//

	Pendulum.PendulumAxis = newaxes(Pendulum.PendulumFrame);
	Pendulum.PendulumAxis.cube_scaling = 'on';
	Pendulum.PendulumAxis.isoview='on';
	Pendulum.PendulumAxis.auto_ticks = ["off","on","off"];
	Pendulum.PendulumAxis.y_location = "origin";
	Pendulum.PendulumAxis.font_size = 3;
	Pendulum.PendulumAxis.background = 17;
	Pendulum.PendulumAxis.thickness = 3;
	Pendulum.PendulumAxis.margins = [0,0,0,0]; 
	Pendulum.PendulumAxis.auto_margins = "off";
	Pendulum.PendulumAxis.tight_limits = ["on","on","on"];

	//==================== Input Frame.====================//

	Pendulum.InputFrame = uicontrol(Pendulum.App,....
	'unit','normalized',....
	'BackgroundColor',[-1,-1,-1],....
	'Position',[0,0,1,0.3],....
	'Relief','ridge',....
	'Style','frame');

	//--------------------DataInput Frame.------------------  //;

	Pendulum.DataInputFrame = uicontrol(Pendulum.InputFrame,....
	'unit','normalized',....
	'BackgroundColor',[-1,-1,-1],....
	'Position',[0.025,0.05,0.45,0.90],....
	'Relief','ridge',....
	'Style','frame',....
	'layout', 'gridbag',....
	'margin', [5 5 5 5]);

	//                Label for length of pendullum.           //

	Pendulum.Const.grid = [1,1,2,1];
	Pendulum.Const.padding = [5,5];
	Pendulum.LengthLabel = uicontrol(Pendulum.DataInputFrame,....
	'unit','normalized',....
	'FontName','Arial Nova Cond Light',....
	'FontSize',[15],....
	'FontWeight','bold',....
	'HorizontalAlignment','center',....
	'Position',[0.02,0.8,0.15,0.15],....
	'Relief','default',....
	'String',"Length of pendulum = 1 m",....
	'Style','text',....
	'constraints', Pendulum.Const,....
	'margins', [2 0 0 0]);

	//                 Label for initial angle.                 //

	Pendulum.Const.grid = [3,1,2,1];
	Pendulum.AngleLabel = uicontrol(Pendulum.DataInputFrame,....
	'unit','normalized',....
	'FontName','Arial Nova Cond Light',....
	'FontSize',[15],....
	'FontWeight','bold',....
	'HorizontalAlignment','center',...
	'Position',[0.02,0.8,0.15,0.15],.....
	'Relief','default',....
	'String','Initial Angle = 45',....
	'Style','text',....
	'constraints', Pendulum.Const,....
	'margins', [2 5 0 0]);


	//                 Slider for length of pendullum.           //

	Pendulum.Const.grid = [1,2,2,1];
	Pendulum.Length = uicontrol(Pendulum.DataInputFrame,....
	'unit','normalized',....
	'Style','slider',....
	'Callback','PendulumChange(Pendulum)',....
	'min',[0.1],....
	'max',100,....
	'value',[1],....
	'SliderStep',[0.01,0.1],....
	'constraints', Pendulum.Const,....
	'SnapToTicks','on',....
	'margins', [0 0 2 0]);

	//                  Slider for initial angle.                //

	Pendulum.Const.grid = [3,2,2,1];
	Pendulum.Angle = uicontrol(Pendulum.DataInputFrame,....
	'unit','normalized',....
	'Style','slider',....
	'Callback','PendulumChange(Pendulum)',....
	'min',-179.9,....
	'max',179.9,....
	'value',[45],....
	'SliderStep',[0.1,0.5],....
	'constraints', Pendulum.Const,....
	'SnapToTicks','on',....
	'margins', [0 5 2 0]);

	//                   Label for g.                           //

	Pendulum.Const.grid = [1,3,2,1];
	Pendulum.gLabel = uicontrol(Pendulum.DataInputFrame,....
	'unit','normalized',....
	'FontName','Arial Nova Cond Light',....
	'FontSize',[15],....
	'FontWeight','bold',....
	'HorizontalAlignment','center',....
	'Position',[0.02,0.8,0.15,0.15],....
	'String','g = 9.81 m/s^2',....
	'Style','text',....
	'constraints', Pendulum.Const,....
	'margins', [2 0 2 0]);

	//                   Label for Simulation speed.             //

	Pendulum.Const.grid = [3,3,2,1];
	Pendulum.SpeedLabel = uicontrol(Pendulum.DataInputFrame,....
	'unit','normalized',....
	'FontName','Arial Nova Cond Light',....
	'FontSize',[15],....
	'FontWeight','bold',....
	'HorizontalAlignment','center',....
	'Position',[0.02,0.8,0.15,0.15],....
	'String','Simulation Speed = Realtime',....
	'Style','text',....
	'constraints', Pendulum.Const,....
	'margins', [2 5 2 0]);

	//                    Slider for g.                         //

	Pendulum.Const.grid = [1,4,2,1];
	Pendulum.g = uicontrol(Pendulum.DataInputFrame,....
	'unit','normalized',....
	'Style','slider',....
	'Callback','Pendulum.gLabel.string=''g = ''+msprintf(''%2.2f'',Pendulum.g.value)+'' m/s^2''',....
	'min',0.1,....
	'max',100,....
	'value',[9.81],....
	'SliderStep',[0.01,.1],....
	'constraints', Pendulum.Const,....
	'SnapToTicks','on',....
	'margins', [2 0 2 0]);

	//                 Slider for Simulation speed.            //

	Pendulum.Const.grid = [3,4,2,1];
	Pendulum.Speed = uicontrol(Pendulum.DataInputFrame,....
	'unit','normalized',....
	'Style','slider',....
	'Callback','PendulumSpeed(Pendulum)',....
	'min',0.1,....
	'max',0.001,....
	'value',[1/100],....
	'SliderStep',[0.0001,0.0005],....
	'constraints', Pendulum.Const,....
	'margins', [2 5 2 0],....
	'Callback_Type',2);

	//                     Start btn.                         //

	Pendulum.Const.grid = [1,5,2,1];
	Pendulum.StartBtn = uicontrol(Pendulum.DataInputFrame,... 
	'unit','normalized',....
	'BackgroundColor',[0.1,0.5,0.5],....
	'FontName','Gabriola',....
	'FontSize',[25],'HorizontalAlignment','center','Position',[0.6,0.0,0.3,0.1],'Relief','raised','String','Start','Style','pushbutton','Callback','PendulumStart(Pendulum)', 'tooltip', 'start simulation','constraints', Pendulum.Const,'margins', [0 20 2 20],'Callback_Type',2,'value',1);

	//                      Pause btn.                       //

	Pendulum.Const.grid = [3,5,1,1];
	Pendulum.PauseBtn = uicontrol(Pendulum.DataInputFrame,.... 
	'unit','normalized',....
	'BackgroundColor',[0.8,0.3,0.2],....
	'FontName','Gabriola',....
	'FontSize',[25],.....
	'HorizontalAlignment','center',....
	'Position',[0.8,0.02,0.3,0.1],.....
	'Relief','raised',....
	'String','Pause',....
	'Style','pushbutton',....
	'Callback','PendulumPause(Pendulum)',....
	'tooltip', 'Pause simulation',....
	'constraints', Pendulum.Const,....
	'margins', [2 20 2 20],....
	'Callback_Type',12,....
	'Enable','off');


	//                      Reset btn.                        //

	Pendulum.Const.grid = [4,5,1,1];
	Pendulum.StopBtn = uicontrol(Pendulum.DataInputFrame,....
	'unit','normalized',....
	'BackgroundColor',[0.7,0.3,0.5],....
	'FontName','Gabriola',....
	'FontSize',[25],....
	'HorizontalAlignment','center',....
	'Position',[0.8,0.02,0.3,0.1],....
	'Relief','raised',....
	'String','Reset',....
	'Style','pushbutton',.....
	'Callback','PendulumStop(Pendulum)',....
	'tooltip', 'Reset simulation',....
	'constraints', Pendulum.Const,....
	'margins', [2 20 2 20],....
	'Callback_Type',12);

	//---------------------  PlotInput Frame.---------------------//

	Pendulum.PlotInputFrame = uicontrol(Pendulum.InputFrame,....
	'unit','normalized',....
	'Position',[0.525,0.05,0.45,0.90],....
	'Relief','ridge',....
	'Style','frame',....
	'layout', 'gridbag',....
	'margin', [5 5 5 5]);

	//                    No. of oscilltions Label               //

	Pendulum.Const.grid = [1,1,2,1];
	Pendulum.NoLabel = uicontrol(Pendulum.PlotInputFrame,....
	'unit','normalized',.....
	'FontName','Gabriola',....
	'FontSize',[15],....
	'FontWeight','bold',....
	'HorizontalAlignment','center',....
	'Relief','default',....
	'String','Number of oscillations :',....
	'Style','text',....
	'constraints', Pendulum.Const,....
	'margins', [5 2 5 2]);

	//                    No. of oscilltions                //

	Pendulum.Const.grid = [3,1,1,1];
	Pendulum.Num = uicontrol(Pendulum.PlotInputFrame,....
	'unit','normalized',.....
	'FontName','Gabriola',....
	'FontSize',[15],....
	'FontWeight','bold',....
	'HorizontalAlignment','center',....
	'Relief','default',....
	'String','20',....
	'Style','text',....
	'constraints', Pendulum.Const,....
	'margins', [5 2 5 2]);

	//                Slider for no of oscillatins.            //

	Pendulum.Const.grid = [4,1,1,1];
	Pendulum.NO = uicontrol(Pendulum.PlotInputFrame,....
	'unit','normalized',....
	'Style','slider',....
	'min',1,....
	'max',100,....
	'value',[20],....
	'SliderStep',[1,5],....
	'constraints', Pendulum.Const,....
	'margins', [2 5 2 0],....
	'Callback','Pendulum.Num.string = msprintf(''%d'',Pendulum.NO.value)');

	//                      Plot Checkbox                        //

	Pendulum.Const.grid = [1,2,1,1];
	Pendulum.Checkbox = uicontrol(Pendulum.PlotInputFrame,....
	'unit','normalized',....
	'FontName','Gabriola',....
	'FontSize',[15],....
	'FontWeight','bold',....
	'HorizontalAlignment','center',....
	'Relief','default',...
	'String','Plot :',....
	'Style','checkbox',....
	'max',1,....
	'min',0,....
	'value',1,....
	'constraints', Pendulum.Const,....
	'margins', [5 2 5 2]);

	//                      x menu.                             //

	Str = '       '+['t','x','y','θ','dθ/dt','d^2θ/dt^2']
	Pendulum.Const.grid = [2,2,1,1];
	Pendulum.xmenu = uicontrol(Pendulum.PlotInputFrame,....
	'unit','normalized',....
	'FontName','Gabriola',....
	'FontSize',[15],....
	'HorizontalAlignment','center',....
	'Relief','raised',....
	'String',Str,....
	'Value',[1],.....
	'Style','popupmenu',.....
	'Callback','', .....
	'tooltip', 'x',.....
	'constraints', Pendulum.Const,.....
	'margins', [5 2 5 2],.....
	'Callback_Type',2);

	//                      Vs Label                         //

	Pendulum.Const.grid = [3,2,1,1];
	Pendulum.VsLabel = uicontrol(Pendulum.PlotInputFrame,....
	'unit','normalized',.....
	'FontName','Gabriola',....
	'FontSize',[15],....
	'FontWeight','bold',....
	'HorizontalAlignment','center',....
	'Relief','default',....
	'String','VS.',....
	'Style','text',....
	'constraints', Pendulum.Const,....
	'margins', [5 2 5 2]);

	//                        y menu                        //

	Pendulum.Const.grid = [4,2,1,1];
	Pendulum.ymenu = uicontrol(Pendulum.PlotInputFrame,....
	'unit','normalized',....
	'FontName','Gabriola',....
	'FontSize',[15],....
	'HorizontalAlignment','center',....
	'Position',[0.8,0.02,0.3,0.1],....
	'Relief','raised',....
	'String',Str,....
	'Value',[2],....
	'Style','popupmenu',....
	'Callback','',....
	'tooltip', 'y',....
	'constraints', Pendulum.Const,....
	'margins', [5 2 5 2],....
	'Callback_Type',2);

	//======================= Plot Frame ========================//

	Pendulum.PlotFrame = uicontrol(Pendulum.App,....
	'unit','normalized',....
	'BackgroundColor',[0.3,0.2,0.6],....
	'Position',[0.5,0.3,0.5,0.7],....
	'Relief','ridge',....
	'Style','frame');

	//----------------------- Plot Axis --- --------------------//

	Pendulum.PlotAxis = newaxes(Pendulum.PlotFrame);
	Pendulum.PlotAxis.font_size = 3;
	Pendulum.PlotAxis.background = 17;
	Pendulum.PlotAxis.thickness = 3;
	// Needed for smooth scrolling of axis.
	Pendulum.PlotAxis.tight_limits = ["on","on","on"];

	////=======================End of GUI======================////



	///++++++++++++++++++++++++ Setup+++++++++++++++++++++++++///

	//            Initial values                   //

	//Length of pendullum.
	L = Pendulum.Length.value;
	// Acceleration due to gravity.
	g = Pendulum.g.value; 
	// Initial angle in degrees.
	ThetaMaxDegree = Pendulum.Angle.value;

	//       Calculations for initial setup        //

	// X-position of bob at t=0.
	xo = L*sind(ThetaMaxDegree); 
	// Y-position of bob at t=0.
	yo = -L*cosd(ThetaMaxDegree); 

	// -------------- Drawing Initial Setuo -----------------------//

	//      Drawing the bob and rod of the pendullum           //

	sca(Pendulum.PendulumAxis)

	// Creating an arc to repersent the angle.
	xarc(-0.2*L,0.2*L,0.4*L,0.4*L,270*64,ThetaMaxDegree*64) 
	Pendulum.arc = gce();
	Pendulum.arc.thickness = 4; 
	Pendulum.arc.fill_mode = "on";
	Pendulum.arc.background = 21; 
	Pendulum.arc.foreground = 0; 
	Pendulum.arc.clip_state = "clipgrf";

	// Angle text 
	xstring(0,0,'$45^\circ$'); 
	Pendulum.txt=gce(); 
	Pendulum.txt.font_size=4; 
	Pendulum.txt.font_foreground = 7;

	// Rod.
	plot([0,xo],[0,yo],'b','thickness',4); 
	Pendulum.String=gce().children;

	// Piviot point.
	plot(0,0,'ob','markersize',10,'MarkBackground','black'); 

	// Bob.
	plot(xo,yo,'om','markersize',20,'MarkBackground','magenta');
	Pendulum.Bob = gce().children; 
	Pendulum.PendulumAxis.data_bounds=matrix(1.1*[-L,L,-L,L],2,2);

	// Text for time.
	xstring(-0.9*L,0.9*L,'Time : ')
	Pendulum.Time = gce(); Pendulum.Time.font_size = 4;

	// Text for timeperiod.
	xstring(0.1*L,0.9*L,'Time Period : ')
	Pendulum.TimePeriod = gce(); 
	Pendulum.TimePeriod.font_size = 4;

	//               Setup for ploting                  //

	sca(Pendulum.PlotAxis)

	// Trajactory
	plot(0,0,'m','thickness',3)
	Pendulum.phase = gce().children;

	// Point
	plot(0,0,'db','markersize',10,'MarkBackground','blue')
	Pendulum.phasepoint=gce().children;

	// Show figure now.
	Pendulum.App.visible = 'on';

	// Function to solve the ode of simple pendullum.
	// $'\dfrac{d^2\theta}{dt^2}=-dfrac{g}{l}*\sin(\theta)'$
	function dtheta = PendulumOdesol(t,theta)
		L = Pendulum.Length.value;
		g = Pendulum.g.value;
		dtheta(1) = theta(2);
		dtheta(2) = -(g/L)*sin(theta(1));
	endfunction

	// Function used to calcualte the elliptic integral.
	function T = PendulumElliptic(phi)
		T = 1/sqrt(1-sin(ThetaMaxRadian/2)^2*sin(phi)^2);
	endfunction


	///%%%%%%%%%%%%%%%%%%%% Callback Functions %%%%%%%%%%%%%%%%%%%///


	// Callback function for Length and Angle Slider.

	function PendulumChange(Pendulum)
		L = Pendulum.Length.value;
		ThetaMaxDegree = Pendulum.Angle.value;
		x = L*sind(ThetaMaxDegree);
		y = -L*cosd(ThetaMaxDegree);
		drawlater();
		Pendulum.String.data=[0,0; x, y]
		Pendulum.Bob.data=[x,y]
		Pendulum.Time.data = [-0.9*L,0.9*L]
		Pendulum.TimePeriod.data = [0.2*L,0.9*L]
		Pendulum.LengthLabel.string = 'Length of pendullum = '+string(L)+' m';
		Pendulum.AngleLabel.string = 'Initial Angle = '+string(ThetaMaxDegree);
		Pendulum.txt.text='$'+msprintf('%0.1f',ThetaMaxDegree)+'^\circ$';
		Pendulum.PendulumAxis.data_bounds=matrix(1.1*[-L,L,-L,L],2,2);
		Pendulum.arc.data = [-0.2*L,0.2*L,0.4*L,0.4*L,270,ThetaMaxDegree]
		Pendulum.Time.text = 'Time : ';
		Pendulum.TimePeriod.text = 'Time Period : ';
		Pendulum.StartBtn.value=1;
		drawnow()
	endfunction

	function PendulumStart(Pendulum)
		Pendulum.StartBtn.Enable = 'off';
		Pendulum.StopBtn.Enable = 'off';
		Pendulum.PauseBtn.Enable = 'on';
		i = Pendulum.StartBtn.value;
		L = Pendulum.Length.value;
		ThetaMaxDegree = Pendulum.Angle.value;
		ThetaMaxRadian = ThetaMaxDegree * %pi/180;
		g = Pendulum.g.value;
		dt = Pendulum.Speed.value;
		// Time period for small amplitude.
		T = 2*%pi*sqrt(L/g);
		// No of ossiclations.
		N = Pendulum.NO.value; 
		// Solving elliptic integral of first kind
		K = intg(0,%pi/2,PendulumElliptic);
		TimePeriod  = 4*sqrt(L/g)*K;
		// Defining range of time.
		ti=linspace(0,TimePeriod,int(TimePeriod*100));
		sol = ode([ThetaMaxRadian;0],0,ti,PendulumOdesol);
		// theta in degrees.
		thetai = sol(1,:)*180/%pi; 
		thetadti = sol(2,:)*180/%pi;
		n=size(ti,'*')
		t=ti; theta =thetai; thetadt=thetadti;
		for j = 1:N-1
			t(1,j*n+1:n*(j+1))=ti+TimePeriod*j
			theta(1,j*n+1:n*(j+1))=thetai;
			thetadt(1,j*n+1:n*(j+1))=thetadti
		end
		d2theta = -(g/L)*sind(theta);
		// x- Position of the pendullum.
		x = L*sind(theta); 
		// y- Position of the pendullum.
		y = -L*cosd(theta); 

		xselect = Pendulum.xmenu.value;
		yselect = Pendulum.ymenu.value;
		if xselect == 1 then
			X = t;
			xlabel('time (s)', 'fontsize',5 );
		elseif xselect == 2
			X = x;
			xlabel('x(t)', 'fontsize',5 );
		elseif xselect == 3
			X = y;
			xlabel('y(t)', 'fontsize',5 );
		elseif xselect == 4
			X = theta;
			xlabel('$\theta$', 'fontsize',5 );
		elseif xselect == 5
			X = thetadt;
			xlabel('$\dfrac{d\theta}{dt}$', 'fontsize',5);
		elseif xselect == 6
			X = d2theta;
			xlabel('$\dfrac{d^2\theta}{dt^2}$', 'fontsize',5);
		end

		if yselect == 1 then
			Y = t;
			ylabel('time (s)', 'fontsize',5 );
		elseif yselect == 2
			Y = x;
			ylabel('x(t)', 'fontsize',5 );
		elseif yselect == 3
			Y = y;
			ylabel('y(t)', 'fontsize',5 );
		elseif yselect == 4
			Y = theta;
			ylabel('$\theta$', 'fontsize',5 );
		elseif yselect == 5
			Y = thetadt;
			ylabel('$\dfrac{d\theta}{dt}$', 'fontsize',5,'rotation',0);
		elseif yselect == 6
			Y = d2theta;
			ylabel('$\dfrac{d^2\theta}{dt^2}$', 'fontsize',5,'rotation',0);
		end

		// Setting simulation time//
		realtimeinit(dt);
		Pendulum.PlotAxis.data_bounds=1.05*matrix([min(X),max(X),min(Y),max(Y)],2,2);
		if xselect == 1 
			Pendulum.PlotAxis.data_bounds=matrix([0,2.1*TimePeriod,1.05*min(Y),1.05*max(Y)],2,2)
		end
		Pendulum.TimePeriod.text = 'Time Period : '+msprintf('%0.2f ',TimePeriod) + " s";
		if yselect == 1 
			Pendulum.PlotAxis.data_bounds=matrix([1.05*min(X),1.05*max(X),0,2.1*TimePeriod],2,2)
		end
		Pendulum.TimePeriod.text = 'Time Period : '+msprintf('%0.2f ',TimePeriod) + " s";
		// Animation loop //
		for k=i:size(x,"*")
			realtime(k);
			drawlater
			Pendulum.String.data=[0,0; x(k), y(k)]
			Pendulum.Bob.data=[x(k),y(k)]
			Pendulum.arc.data(:,6)= theta(k)
			Pendulum.txt.text='$'+msprintf('%0.1f',theta(k))+'^\circ$';
			Pendulum.Time.text = 'Time : '+msprintf('%0.2f ',t(k)) + " s"
			if Pendulum.Checkbox.value ==1
				if k>3*n then
					f = int(k/(n))-2;
					Pendulum.phase.data=[X(f*n:k)',Y(f*n:k)'];
				else
					Pendulum.phase.data=[X(1:k)',Y(1:k)'];
				end
				Pendulum.phasepoint.data=[X(k),Y(k)];
				if xselect == 1 && X(k)>2*TimePeriod
					Pendulum.PlotAxis.data_bounds=matrix([X(k)-2*TimePeriod,X(k)+0.1*TimePeriod,1.05*min(Y),1.05*max(Y)],2,2)
				end
				if yselect == 1 && Y(k)>2*TimePeriod
					Pendulum.PlotAxis.data_bounds=matrix([1.05*min(X),1.05*max(X),Y(k)-2*TimePeriod,Y(k)+0.1*TimePeriod],2,2)
				end
			end
			drawnow
			Pendulum.StartBtn.value = k + 1;
		end
		Pendulum.StartBtn.value = 1;
		Pendulum.StartBtn.Enable = 'on';
		Pendulum.StopBtn.Enable = 'on';
		Pendulum.PauseBtn.Enable = 'off';
	endfunction

	function PendulumStop(Pendulum)
		PendulumChange(Pendulum)
		Pendulum.phase.data=[0,0]
		Pendulum.phasepoint.data=[0,0]
		Pendulum.Speed.value = 1/100;
		Pendulum.SpeedLabel.string='Simulation Speed = Realtime';
		realtime(0)
		abort()
	endfunction

	function PendulumSpeed(Pendulum)
		if Pendulum.Speed.value == 1/100 then
			Pendulum.SpeedLabel.string='Simulation Speed = Realtime';
		elseif Pendulum.Speed.value > 1/100
			Pendulum.SpeedLabel.string='Simulation Speed = Slow';
		else
			Pendulum.SpeedLabel.string='Simulation Speed = Fast';
		end
		realtimeinit(Pendulum.Speed.value);
	endfunction

	function PendulumPause(Pendulum)
		Pendulum.StartBtn.Enable = 'on';
		Pendulum.StopBtn.Enable = 'on';
		Pendulum.PauseBtn.Enable = 'off';
		abort();
	endfunction

	[Pendulum,PendulumOdesol,PendulumElliptic,PendulumChange,PendulumStart,PendulumStop,PendulumSpeed,PendulumPause] = resume(Pendulum,PendulumOdesol,PendulumElliptic,PendulumChange,PendulumStart,PendulumStop,PendulumSpeed,PendulumPause);
endfunction

p=help_skeleton('pendulumgui','/home/manish/Documents/SCILAB/pendulumgui/help/en_US/')
if (isdef('editor') | (funptr('editor')<>0)) then
  editor(p);
end
